@@ -10,11 +10,20 @@ from nicovideo_api_client.constants import DEFAULT_RETRY, END_POINT_URL_V2
 
 
 class SnapshotSearchAPIV2Request:
-    def __init__(self, query: Dict[str, str], limit: int):
+    def __init__(
+        self,
+        query: Dict[str, str],
+        limit: int,
+        user_agent: Tuple[str, str, str],
+    ):
         self._query: Dict[str, str] = query
         self._limit = limit
+        self._user_agent = user_agent
 
-    def request(self, timeout: float = 400.0) -> SnapshotSearchAPIV2Result:
+    def request(
+        self,
+        timeout: float = 400.0,
+    ) -> SnapshotSearchAPIV2Result:
         """
         API にリクエストを送り、レスポンスを返す。
 
@@ -26,6 +35,7 @@ class SnapshotSearchAPIV2Request:
         また、`timeout` のうち 1/4 を接続時間に、 3/4 を読み込み時間に割り当てている。
         :return: レスポンスオブジェクト
         """
+
         if self._limit <= 100:
             self._query["_limit"] = str(self._limit)
         else:
@@ -53,14 +63,22 @@ class SnapshotSearchAPIV2Request:
         return SnapshotSearchAPIV2Result(self._query, results)
 
     def _request(
-        self, timeout: float, total_time: float
+        self,
+        timeout: float,
+        total_time: float,
     ) -> Tuple[SnapshotSearchAPIV2Result, float]:
         # `'jsonFilter'` の値までまとめてエンコードされてしまっているので、それを避けるため True にしている
         # TODO: `'q'` がエンコードされずよくないので原因調査して修正する。
         url = self.build_url(True if "jsonFilter" in self._query else False)
 
+        header = {"User-Agent": self._user_agent[0] + "/" + self._user_agent[1]}
+        if self._user_agent[2] != "":
+            header["User-Agent"] += " " + self._user_agent[2]
+
         for r in range(DEFAULT_RETRY):
-            response = requests.get(url, timeout=(timeout / 4, timeout * 3 / 4))
+            response = requests.get(
+                url, timeout=(timeout / 4, timeout * 3 / 4), headers=header
+            )
             response_time = response.elapsed.total_seconds()
             response_obj = SnapshotSearchAPIV2Result(self._query, response)
             total_time += response_time
